Exception: Neo4j::Driver::Exceptions::AuthorizationExpiredException
- Inherits:
-
SecurityException
- Object
- RuntimeError
- Neo4jException
- ClientException
- SecurityException
- Neo4j::Driver::Exceptions::AuthorizationExpiredException
- Defined in:
- lib/neo4j/driver/exceptions/authorization_expired_exception.rb
Overview
The authorization info maintained on the server has expired. The client should reconnect.
Error code: Neo.ClientError.Security.AuthorizationExpired
Constant Summary collapse
- DESCRIPTION =
'Authorization information kept on the server has expired, this connection is no longer valid.'
Instance Attribute Summary
Attributes inherited from Neo4jException
#classification, #code, #diagnostic_record, #gql_cause, #gql_status, #raw_classification, #status_description, #suppressed
Method Summary
Methods inherited from ClientException
Methods inherited from Neo4jException
Constructor Details
This class inherits a constructor from Neo4j::Driver::Exceptions::Neo4jException