Exception: Neo4j::Driver::Exceptions::FatalDiscoveryException
- Inherits:
-
ClientException
- Object
- RuntimeError
- Neo4jException
- ClientException
- Neo4j::Driver::Exceptions::FatalDiscoveryException
- Defined in:
- lib/neo4j/driver/exceptions/fatal_discovery_exception.rb
Overview
This error indicate a fatal problem to obtain routing tables such as the routing table for a specified database does not exist. This exception should not be retried.
Instance Attribute Summary
Attributes inherited from Neo4jException
#classification, #code, #diagnostic_record, #gql_cause, #gql_status, #raw_classification, #status_description, #suppressed
Method Summary
Methods inherited from ClientException
Methods inherited from Neo4jException
Constructor Details
This class inherits a constructor from Neo4j::Driver::Exceptions::Neo4jException