Exception: Neo4j::Driver::Exceptions::SessionExpiredException
- Inherits:
-
Neo4jException
- Object
- RuntimeError
- Neo4jException
- Neo4j::Driver::Exceptions::SessionExpiredException
- Defined in:
- lib/neo4j/driver/exceptions/session_expired_exception.rb
Overview
A SessionExpiredException indicates that the session can no longer satisfy the criteria under which it was acquired, e.g. a server no longer accepts write requests. A new session needs to be acquired from the driver and all actions taken on the expired session must be replayed.
Instance Attribute Summary
Attributes inherited from Neo4jException
#classification, #code, #diagnostic_record, #gql_cause, #gql_status, #raw_classification, #status_description, #suppressed
Method Summary
Methods inherited from Neo4jException
Constructor Details
This class inherits a constructor from Neo4j::Driver::Exceptions::Neo4jException